# eric7.Project

Package implementing the project management module of eric.

The project management module consists of the main part, which is used for reading and writing of eric4, eric5, eric6 and eric7 project files (*.e4p, *.epj) and for performing all operations on the project. It is accompanied by various UI related modules implementing different dialogs and a tabbed tree browser for the display of files belonging to the current project as well as the project model related modules.

### Modules

AddDirectoryDialog | Module implementing a dialog to add files of a directory to the project.
AddFileDialog | Module implementing a dialog to add a file to the project.
AddFoundFilesDialog | Module implementing a dialog to show the found files to the user.
AddLanguageDialog | Module implementing a dialog to add a new language to the project.
CreateDialogCodeDialog | Module implementing a dialog to generate code for a Qt5 dialog.
DebuggerPropertiesDialog | Module implementing a dialog for entering project specific debugger settings.
DebuggerPropertiesFile | Module implementing a class representing the project debugger properties JSON file.
FileCategoryRepositoryItem | Module implementing a data structure holding the data associated with a file type category.
FiletypeAssociationDialog | Module implementing a dialog to enter filetype associations for the project.
LexerAssociationDialog | Module implementing a dialog to enter lexer associations for the project.
MakePropertiesDialog | Module implementing a dialog to enter the properties for 'make'.
NewDialogClassDialog | Module implementing a dialog to enter the data for a new dialog class file.
NewPythonPackageDialog | Module implementing a dialog to add a new Python package.
Project | Module implementing the project management functionality.
ProjectBaseBrowser | Module implementing the baseclass for the various project browsers.
ProjectBrowser | Module implementing the project browser part of the eric UI.
ProjectBrowserModel | Module implementing the browser model.
ProjectBrowserRepositoryItem | Module implementing a data structure holding the data associated with a project browser type.
ProjectBrowserSortFilterProxyModel | Module implementing the browser sort filter proxy model.
ProjectFile | Module implementing a class representing the project JSON file.
ProjectFormsBrowser | Module implementing a class used to display the forms part of the project.
ProjectOthersBrowser | Module implementing a class used to display the parts of the project, that don't fit the other categories.
ProjectResourcesBrowser | Module implementing a class used to display the resources part of the project.
ProjectSourcesBrowser | Module implementing a class used to display the Sources part of the project.
ProjectTranslationsBrowser | Module implementing a class used to display the translations part of the project.
ProjectVenvConfigurationDialog | Module implementing a dialog to enter the configuration for the embedded environment of the project.
ProjectVenvCreationParametersDialog | Module implementing a dialog to enter the parameters for the creation of the embedded virtual environment.
PropertiesDialog | Module implementing the project properties dialog.
QuickFindFileDialog | Module implementing a quick search for files.
RccCompilerOptionsDialog | Module implementing a dialog to enter some non-common rcc compiler options.
SpellingPropertiesDialog | Module implementing the Spelling Properties dialog.
TranslationPropertiesDialog | Module implementing the Translations Properties dialog.
UicCompilerOptionsDialog | Module implementing a dialog to enter some non-common uic compiler options.
UicLoadUi5 | Module to get the object name, class name or signatures of a Qt form (*.ui).
UicLoadUi6 | Module to get the object name, class name or signatures of a Qt form (*.ui).
UserProjectFile | Module implementing a class representing the user project JSON file.
UserPropertiesDialog | Module implementing the user specific project properties dialog.